summaryrefslogtreecommitdiffstats
path: root/libtdepim/qutf7codec.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/qutf7codec.cpp')
-rw-r--r--libtdepim/qutf7codec.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/libtdepim/qutf7codec.cpp b/libtdepim/qutf7codec.cpp
index d390e649..dc8ef2a2 100644
--- a/libtdepim/qutf7codec.cpp
+++ b/libtdepim/qutf7codec.cpp
@@ -18,7 +18,7 @@
with any version of TQt by TrollTech AS, Norway. In this case, the
use of this plugin doesn't cause the resulting executable to be
covered by the GNU General Public License.
- This exception does not however invalidate any other reasons why the
+ This exception does not however tqinvalidate any other reasons why the
executable file might be covered by the GNU General Public License.
*/
@@ -137,10 +137,10 @@ int TQUtf7Codec::heuristicContentMatch(const char* chars, int len) const
}
class TQUtf7Decoder : public TQTextDecoder {
// the storage for our unicode char until it's finished
ushort uc;
// the state of the base64 decoding
// can be 0 (just finished three unicode chars)
// 1 (have the upper 6 bits of uc already)
// 2 (have the upper 12 bits of uc already)
// 3 (have the upper 2 bits of uc already)
@@ -148,7 +148,7 @@ class TQUtf7Decoder : public TQTextDecoder {
// 7 (have the upper 10 bits of uc already)
// => n (have the upper (n * 6) % 16 bits of uc already)
// "stepNo" cycles through all it's values every three
- // unicode chars.
+ // tqunicode chars.
char stepNo;
// remembers if we are in shifted-sequence mode
bool shifted;
@@ -462,7 +462,7 @@ public:
#endif
// source and destination cursor
- const TQChar * s = uc.unicode();
+ const TQChar * s = uc.tqunicode();
TQCString::Iterator t = result.data();
if ( uc.isNull() ) {
@@ -473,7 +473,7 @@ public:
// normal operation:
for (int i = 0 ; i < len_in_out ;
i++/*, checkOutBuf(result,maxreslen,t,i,len_in_out,5)*/ ) {
- ushort ch = s[i].unicode();
+ ushort ch = s[i].tqunicode();
//
// first, we check whether we might get around encoding:
@@ -137,10 +137,10 @@ int TQUtf7Codec::heuristicContentMatch(const char* chars, int len) const
}
class TQUtf7Decoder : public TQTextDecoder {
- // the storage for our unicode char until it's finished
+ // the storage for our tqunicode char until it's finished
ushort uc;
// the state of the base64 decoding
@@ -137,10 +137,10 @@ int TQUtf7Codec::heuristicContentMatch(const char* chars, int len) const
ushort uc;
// the state of the base64 decoding
- // can be 0 (just finished three unicode chars)
+ // can be 0 (just finished three tqunicode chars)
// 1 (have the upper 6 bits of uc already)
// 2 (have the upper 12 bits of uc already)